@@ -95,9 +95,10 @@ class DetaModel(BaseModel):
     def create(cls, source: Union[dict, BaseModel],
                *,
                expire_in: Optional[int] = None,
-               expire_at: Union[None, int, float, datetime] = None):
+               expire_at: Union[None, int, float, datetime] = None,
+               **kwargs):
         obj = cls.convert_from(source)
-        if obj and obj.save(expire_in=expire_in, expire_at=expire_at):
+        if obj and obj.save(expire_in=expire_in, expire_at=expire_at, **kwargs):
             return obj
             
     @classmethod
@@ -146,13 +147,9 @@ class DetaModel(BaseModel):
     def save(self, *,
              expire_in: Optional[int] = None,
              expire_at: Union[None, int, float, datetime] = None,
-             exclude_none: bool = False,
-             exclude_unset: bool = False):
+             **kwargs):
         db = self.get_base()
-        data = self.dict(
-            exclude_none=exclude_none,
-            exclude_unset=exclude_unset,
-        )
+        data = self.dict(**kwargs)
 
         returned_data = db.put(data, expire_in=expire_in, expire_at=expire_at)
 
